@@ -1,6 +1,7 @@
 from pathlib import Path
 import json
 import cv2
+import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
 import os
 from zebrazoom.code.vars import getGlobalVariables
 globalVariables = getGlobalVariables()
@@ -33,7 +34,7 @@ def getConfig(config, variableName, videoPath):
       
       cap = 0
       if len(videoPath):
-        cap = cv2.VideoCapture(videoPath)
+        cap = zzVideoReading.VideoCapture(videoPath)
       if (len(videoPath) == 0) or (cap.isOpened() == False):
         print("Error opening video stream or file in getConfig")
         if variableName == "firstFrame":
@@ -105,7 +106,7 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   hyperparameters["fillGapFrameNb"]             = getConfig(config, "fillGapFrameNb", videoPath)
   hyperparameters["minPixelDiffForBackExtract"] = getConfig(config, "minPixelDiffForBackExtract", videoPath)
   hyperparameters["outputFolder"]               = getConfig(config, "outputFolder", videoPath)
-  hyperparameters["videoName"]                  = videoName[0:(len(videoName)-4)]
+  hyperparameters["videoName"]                  = videoName[0:(len(videoName)-4)] # Need to improve this!
   hyperparameters["detectBoutMinNbFrames"]      = getConfig(config, "detectBoutMinNbFrames", videoPath)
   hyperparameters["detectBoutMinDist"]          = getConfig(config, "detectBoutMinDist", videoPath)
   hyperparameters["nbRowsOfWells"]              = getConfig(config, "nbRowsOfWells", videoPath)
@@ -385,6 +386,27 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   
   hyperparameters["postProcessLowProbabilityDetectionPercentOfMaximum"] = getConfig(config, "postProcessLowProbabilityDetectionPercentOfMaximum", videoPath)
   
+  hyperparameters["createPandasDataFrameOfParameters"] = getConfig(config, "createPandasDataFrameOfParameters", videoPath)
+  
+  hyperparameters["frameStepForDistanceCalculation"] = getConfig(config, "frameStepForDistanceCalculation", videoPath)
+  
+  hyperparameters["addBlackLineToImg_Width"] = getConfig(config, "addBlackLineToImg_Width", videoPath)
+  
+  hyperparameters["headEmbededMaxAngleBetweenSubsequentSegments"] = getConfig(config, "headEmbededMaxAngleBetweenSubsequentSegments", videoPath)
+  
+  hyperparameters["saveBodyMask"] = getConfig(config, "saveBodyMask", videoPath)
+  hyperparameters["bodyMask_addWhitePoints"] = getConfig(config, "bodyMask_addWhitePoints", videoPath)
+  hyperparameters["bodyMask_saveAsLabelMeJsonFormat"] = getConfig(config, "bodyMask_saveAsLabelMeJsonFormat", videoPath)
+  hyperparameters["bodyMask_saveAsPngMask"] = getConfig(config, "bodyMask_saveAsPngMask", videoPath)
+  hyperparameters["saveBodyMaskResampleContourNbPoints"] = getConfig(config, "saveBodyMaskResampleContourNbPoints", videoPath)
+  hyperparameters["dontDeleteOutputFolderIfAlreadyExist"] = getConfig(config, "dontDeleteOutputFolderIfAlreadyExist", videoPath)
+  hyperparameters["bodyMask_saveDataForAllFrames"] = getConfig(config, "bodyMask_saveDataForAllFrames", videoPath)
+  
+  hyperparameters["trackingDL"] = getConfig(config, "trackingDL", videoPath)
+  hyperparameters["trackingDLdicotomySearchOfOptimalBlobArea"] = getConfig(config, "trackingDLdicotomySearchOfOptimalBlobArea", videoPath)
+  hyperparameters["applySimpleThresholdOnPredictedMask"] = getConfig(config, "applySimpleThresholdOnPredictedMask", videoPath)
+  hyperparameters["simpleThresholdCheckMinForMaxCountour"] = getConfig(config, "simpleThresholdCheckMinForMaxCountour", videoPath)
+  
   
   if hyperparameters["tailAnglesHeatMap"]:
     hyperparameters["calculateAllTailAngles"] = 1
